@@ -29,7 +29,7 @@
 #' credible intervals when the prior satisfies `P(sigma > sigma_lt) = 0.05` and
 #' `P(range < range_gt) = 0.05`, where `sigma_lt` is between 2.5 to 40 times
 #' the true marginal standard deviation and `range_gt` is between 1/10 and 1/2.5
-#' of the true range." Also see [INLA::inla.spde2.pcmatern()].
+#' of the true range."
 #'
 #' @details
 #' Keep in mind that the range is dependent on the units and scale of the
@@ -61,6 +61,7 @@
 #' @param tweedie_p A `normal()` prior for the Tweedie power parameter. Note the
 #'   parameter has support `1 < tweedie_p < 2` so choose a mean appropriately.
 #' @param b `normal()` priors for the main population-level 'beta' effects.
+#' @param sigma_G `halfnormal()` priors for the random intercept SDs.
 #'
 #' @rdname priors
 #'
@@ -74,11 +75,13 @@ sdmTMBpriors <- function(
   phi = halfnormal(NA, NA),
   ar1_rho = normal(NA, NA),
   tweedie_p = normal(NA, NA),
-  b = normal(NA, NA)
+  b = normal(NA, NA),
+  sigma_G = halfnormal(NA, NA)
 ) {
   assert_that(attr(matern_s, "dist") == "pc_matern")
   assert_that(attr(matern_st, "dist") == "pc_matern")
   assert_that(attr(phi, "dist") == "normal")
+  assert_that(attr(sigma_G, "dist") == "normal")
   assert_that(attr(tweedie_p, "dist") == "normal")
   assert_that(attr(b, "dist") %in% c("normal", "mvnormal"))
   list(
@@ -87,7 +90,8 @@ sdmTMBpriors <- function(
     phi = phi,
     ar1_rho = ar1_rho,
     tweedie_p = tweedie_p,
-    b = b
+    b = b,
+    sigma_G = sigma_G
   )
 }
 
@@ -147,8 +151,7 @@ mvnormal <- function(location = 0, scale = diag(length(location))) {
 #' pc_matern(range_gt = 5, sigma_lt = 1)
 #' plot_pc_matern(range_gt = 5, sigma_lt = 1)
 #'
-#' if (inla_installed()) {
-#'
+#' \donttest{
 #' d <- subset(pcod, year > 2011)
 #' pcod_spde <- make_mesh(d, c("X", "Y"), cutoff = 30)
 #'
@@ -192,7 +195,6 @@ mvnormal <- function(location = 0, scale = diag(length(location))) {
 #'     matern_s = pc_matern(range_gt = 5, sigma_lt = 1),
 #'     matern_st = pc_matern(range_gt = 5, sigma_lt = 1))
 #' )
-#'
 #' }
 pc_matern <- function(range_gt, sigma_lt, range_prob = 0.05, sigma_prob = 0.05) {
   assert_that(range_prob > 0 && range_prob < 1)
